pub fn build_ed25519_component(
signing_key: &SigningKey,
message: &[u8],
) -> Result<ComponentSignature, CompositeError>Expand description
Build a real Ed25519 component signature. Used for testing and as a reference for plugin authors.
pub fn build_ed25519_component(
signing_key: &SigningKey,
message: &[u8],
) -> Result<ComponentSignature, CompositeError>Build a real Ed25519 component signature. Used for testing and as a reference for plugin authors.